bread.contrib.workflows.models package
======================================

.. automodule:: bread.contrib.workflows.models
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

bread.contrib.workflows.models.base module
------------------------------------------

.. automodule:: bread.contrib.workflows.models.base
   :members:
   :undoc-members:
   :show-inheritance:

bread.contrib.workflows.models.nodes module
-------------------------------------------

.. automodule:: bread.contrib.workflows.models.nodes
   :members:
   :undoc-members:
   :show-inheritance:
